@@ -57,7 +57,7 @@ def wait_for_enter():
 def get_package_name():
     with open("./setup.py", "r") as fp:
         nameline = next(
-            (l.strip() for l in fp if l.startswith("NAME = ")), None
+            (line.strip() for line in fp if line.startswith("NAME = ")), None
         )
         return nameline.split("=")[-1].strip().strip('"')
 
